@@ -1,11 +1,11 @@
+use crate::*;
+use indicatif::ProgressBar;
 #[allow(unused_imports)]
 use std::f64::consts::TAU;
 
 #[cfg(feature = "plotters")]
 #[test]
 fn planar() {
-    use crate::*;
-    use indicatif::ProgressBar;
     // let target = Mechanism::four_bar(FourBar {
     //     p0: (0., 0.),
     //     a: 0.,
@@ -40,26 +40,30 @@ fn planar() {
     // let target = YU1;
     // let target = HAND;
     // let target = OPEN_CURVE1;
-    let target = TRIANGLE3;
+    let target = TRIANGLE2;
     // let target = CRUNODE;
     // let target = LINE;
     let gen = 40;
     let pb = ProgressBar::new(gen);
-    let (ans, history) = synthesis::synthesis(&target, gen, 200, |r| {
+    let s = synthesis::synthesis(&target, gen, 200, |r| {
         pb.set_position(r.gen);
         true
     });
+    let ans = s.result();
+    let reports = s.reports();
+    let planar = s.func();
     pb.finish();
     let path = Mechanism::four_bar(ans).four_bar_loop(0., 360);
     plot::plot_curve(
         "Synthesis Test",
         &[
-            ("Target", &target, (221, 51, 85)),
-            ("Optimized", &path, (118, 182, 222)),
+            ("Guided Target", &planar.curve),
+            ("Target", &target),
+            ("Optimized", &path),
         ],
         "result.svg",
     );
-    plot::plot_history(&history, "history.svg");
+    plot::plot_history(&reports, "history.svg");
 }
 
 #[allow(dead_code)]
